@@ -6,7 +6,7 @@ def create_destination_request(user, token_info, body):
             entity_type='destination', name=body['name'],
             platform_name=body['platform_name'],
             destination_uuid=body['destination_uuid'], settings=body['settings'],
-            token_info=token_info
+            token_info=token_info, account_uuid=body.get('account_uuid'), product_uuid=body.get('product_uuid'),
         )
     except ApiError as e:
         return dict(status=400, title='Bad Request', detail=e.args[0], type='about:blank'), 400
